/**
 * Returns a reference to the navigator object, which can be queried for information about the application running the script.
 */
function navigator() {
    this.prototype
}
/**
 * Allows web sites to register themselves as possible handlers for content of a particular MIME type.<br>Note: Web sites may only register content handlers for themselves. For security reasons, it's not possible for an extension or web site to register content handlers targeting other sites.
 * @syntax window.navigator.registerContentHandler(mimeType,uri,title);
 * @param {String} mimeType mimeType is the desired MIME type as a string
 * @param {String} uri uri is the URI to the handler as a string
 * @param {String} title title is the title of the handler presented to the user as a string
 * @returns {undefined} 
 * @static
 */
navigator.registerContentHandler = function() {};

/**
 * Returns a Boolean value indicating whether cookies are enabled or not (read-only).
 * @returns {Boolean} 
 * @static
 */
navigator.cookieEnabled;

/**
 * Returns a string representing the platform of the browser.
 * @returns {String} 
 * @static
 */
navigator.platform;

/**
 * Returns the build identifier of the browser.
 * @returns {String} 
 * @static
 */
navigator.buildID;

/**
 * Returns the user agent string for the current browser.
 * @returns {String} 
 * @static
 */
navigator.userAgent;

/**
 * Returns a string that identifies the current operating system.
 * @returns {String} 
 * @static
 */
navigator.oscpu;

/**
 * Returns a PluginArray object, listing the plugins installed in the application.
 * @returns {Array} 
 * @static
 */
navigator.plugins;

/**
 * Returns the name of the browser vendor for the current browser.
 * @returns {String} 
 * @static
 */
navigator.vendor;

/**
 * Allows web sites to register themselves as possible handlers for particular protocols.<br>Note: Web sites may only register protocol handlers for themselves. For security reasons, it's not possible for an extension or web site to register protocol handlers targeting other sites.
 * @syntax window.navigator.registerProtocolHandler(protocol,uri,title);
 * @param {String} protocol protocol is the protocol the site wishes to handle, specified as a string
 * @param {String} uri uri is the URI to the handler as a string. You can include "%s" to indicate where to insert the escaped URI of the document to be handled.
 * @param {String} title title is the title of the handler presented to the user as a string
 * @returns {undefined} 
 * @static
 */
navigator.registerProtocolHandler = function() {};

/**
 * Returns a MimeTypeArray object, which contains a list of MimeType objects representing the MIME types recognized by the browser. 
 * @returns {String} 
 * @static
 */
navigator.mimeTypes;

/**
 * This method indicates whether the current browser is Java-enabled or not.
 * @syntax result=window.navigator.javaEnabled();
 * @returns {Boolean} The return value for this method indicates whether the preference that controls Java is on or off - not whether the browser offers Java support in general.
 * @static
 */
navigator.javaEnabled = function() {};

/**
 * Returns the internal "code" name of the current browser.
 * @returns {String} 
 * @static
 */
navigator.appCodeName;

/**
 * Returns the online status of the browser. The property returns a boolean value, with true for being online and false for being offline. The property sends updates whenever the browser's ability to connect to the network changes. The update occurs when the user follows links or when a script requests a remote page. For example, the property should return false when users click links soon after they lose internet connection.<br>Browsers implement this property differently.<br>In Chrome and Safari, if the browser is not able to connect to a local area network (LAN) or a router, it is offline; all other conditions return true. So while you can assume that the browser is offline when it returns a false value, you cannot assume that a true value necessarily means that the browser can access the internet. You could be getting false positives, such as in cases where the computer is running a virtualization software that has virtual ethernet adapters that are always "connected." Therefore, if you really want to determine the online status of the browser, you should develop additional means for checking. To learn more, see the HTML5 Rocks article, Working Off the Grid.<br>In Firefox and Internet Explorer, switching the browser to offline mode sends a false value. All other conditions return a true value.
 * @returns {Boolean} 
 * @static
 */
navigator.onLine;

/**
 * vendorSub is the substring of the vendor having to do with the vendor version number.
 * @returns {String} 
 * @static
 */
navigator.vendorSub;

/**
 * Returns the name of the browser. The HTML5 specification also allows any browser to return "Netscape" here, for compatibility reasons.<br>Note: Do not rely on this property to return the correct browser name. In Gecko-based browsers (like Firefox) and WebKit-based browsers (like Chrome and Safari) the returned string is "Netscape".
 * @returns {String} 
 * @static
 */
navigator.appName;

/**
 * This property returns the product name of the current browser.<br>Note: Do not rely on this property to return a real product name. Both Gecko and WebKit browsers return "Gecko" as the value of this property.
 * @returns {String} 
 * @static
 */
navigator.product;

/**
 * Returns the user's do-not-track setting. This is "yes" if the user has requested not to be tracked by web sites, content, or advertising.
 * @returns {String} 
 * @static
 */
navigator.doNotTrack;

/**
 * Returns the version of the browser as a string. It may be either a plain version number, like "5.0", or a version number followed by more detailed information. The HTML5 specification also allows any browser to return "4.0" here, for compatibility reasons.
 * @returns {String} 
 * @static
 */
navigator.appVersion;

/**
 * productSub returns the build number of the current browser. 
 * @returns {String} 
 * @static
 */
navigator.productSub;

/**
 * Returns a string representing the language version of the browser.
 * @returns {String} 
 * @static
 */
navigator.language;

/**
 * Represents the navigator prototype object.
 * @syntax navigator.prototype
 * @static
 */
navigator.prototype;

